from _add_use_case_scripts.requestPost  import postLayersToSwagger, postTableToSwagger

def add_table(use_case: str, table_name: str):
    '''
    take the columns and add the mappings at the server
    replace all "/"'s in the internal representation with a "_"
    '''

    columns = [
        "answerTo",
        "date",
        "deleted",
        "id",
        "labels",
        "text",
        "user"   
    ]
    
    columns = { c : c for c in columns }
    columns["UniqueID"] = "id"
    columns["latitude"] = "location//latitude"
    columns["longitude"] = "location//longitude"
    columns["likesNumber"] = "likesUsers//length"
    columns["reportsNumber"] = "usersReports//length"

    table = {
        "name": table_name,
        "mappings": columns
    }

    postTableToSwagger(use_case,table)

def add_layers(use_case:str, table_name: str):
    layers = [
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationLocation_Layer",
            "properties": [
                "UniqueID",
                "user",
                "latitude",
                "longitude"
                
            ],
            "cluster_properties": [
                "latitude",
                "longitude"  
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationTime_Layer",
            "properties": [
                "UniqueID",
                "user",
                "latitude",
                "longitude",
                "date"
                
            ],
            "cluster_properties": [
                "date"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationUser_Layer",
            "properties": [
                "UniqueID",
                "text",
                "user",
                "labels"
                
            ],
            "cluster_properties": [
                "user"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationStatus_Layer",
            "properties": [
                "UniqueID",
                "text",
                "user",
                "deleted",
                "answerTo"
                
            ],
            "cluster_properties": [
                "deleted",
                "answerTo"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationLikeReport_Layer",
            "properties": [
                "UniqueID",
                "text",
                "user",
                "deleted",
                "answerTo",
                "likesNumber",
                "reportsNumber"
                
            ],
            "cluster_properties": [
                "likesNumber",
                "reportsNumber"
            ]
        }
    ]

    postLayersToSwagger(use_case,layers)

def main(use_case: str):
    print("PUBLICATION")
    table_name = "publication"
    add_table(use_case,table_name)
    add_layers(use_case, table_name)